@@ -725,7 +725,7 @@ create_account_details_ui (GoaProvider    *provider,
                                              NULL);
       adw_entry_row_add_suffix (ADW_ENTRY_ROW (data->email_address), data->discovery_status);
 
-      icon = gtk_image_new_from_icon_name ("emblem-default-symbolic");
+      icon = gtk_image_new_from_icon_name ("check-outlined-symbolic");
       gtk_widget_set_tooltip_text (GTK_WIDGET (icon), _("Auto-detected"));
       gtk_widget_add_css_class (GTK_WIDGET (icon), "success");
       gtk_box_append (GTK_BOX (data->discovery_status), GTK_WIDGET (icon));
@@ -774,7 +774,7 @@ create_account_details_ui (GoaProvider    *provider,
       gtk_box_append (GTK_BOX (data->imap_discovery), discovery_label);
       discovery_image = g_object_new (GTK_TYPE_IMAGE,
                                       "accessible-role", GTK_ACCESSIBLE_ROLE_PRESENTATION,
-                                      "icon-name",       "emblem-default-symbolic",
+                                      "icon-name",       "check-outlined-symbolic",
                                       NULL);
       gtk_box_append (GTK_BOX (data->imap_discovery), discovery_image);
       adw_preferences_group_set_header_suffix (ADW_PREFERENCES_GROUP (data->imap_group),
@@ -818,7 +818,7 @@ create_account_details_ui (GoaProvider    *provider,
       gtk_box_append (GTK_BOX (data->smtp_discovery), discovery_label);
       discovery_image = g_object_new (GTK_TYPE_IMAGE,
                                       "accessible-role", GTK_ACCESSIBLE_ROLE_PRESENTATION,
-                                      "icon-name",       "emblem-default-symbolic",
+                                      "icon-name",       "check-outlined-symbolic",
                                       NULL);
       gtk_box_append (GTK_BOX (data->smtp_discovery), discovery_image);
       adw_preferences_group_set_header_suffix (ADW_PREFERENCES_GROUP (data->smtp_group),
@@ -952,7 +952,6 @@ add_account_check_smtp_cb (GoaMailClient *client,
   if (!goa_mail_client_check_finish (client, result, &error))
     {
       data->smtp_had_ssl_errors = (error->code == GOA_ERROR_SSL);
-      g_prefix_error_literal (&error, "SMTP: ");
       goa_provider_dialog_report_error (data->dialog, error);
       return;
     }
@@ -1021,7 +1020,6 @@ add_account_check_imap_cb (GoaMailClient *client,
   if (!goa_mail_client_check_finish (client, result, &error))
     {
       data->imap_had_ssl_errors = (error->code == GOA_ERROR_SSL);
-      g_prefix_error_literal (&error, "IMAP: ");
       goa_provider_dialog_report_error (data->dialog, error);
       return;
     }
@@ -1140,7 +1138,7 @@ add_account (GoaProvider         *provider,
                            "notify::state",
                            G_CALLBACK (add_account_action_cb),
                            task,
-                           0 /* G_CONNECT_DEFAULT */);
+                           G_CONNECT_DEFAULT);
   gtk_widget_grab_focus (data->email_address);
   goa_provider_task_run_in_dialog (task, data->dialog);
 }
@@ -1422,7 +1420,7 @@ refresh_account (GoaProvider         *provider,
                            "notify::state",
                            G_CALLBACK (refresh_account_action_cb),
                            task,
-                           0 /* G_CONNECT_DEFAULT */);
+                           G_CONNECT_DEFAULT);
   goa_provider_task_run_in_dialog (task, data->dialog);
 }
 
