@@ -865,7 +865,7 @@ goa_provider_dialog_push_account (GoaProviderDialog *self,
   gtk_box_append (GTK_BOX (box), group);
 
   row = g_object_new (ADW_TYPE_ENTRY_ROW,
-                      "title", _("_Account Name"),
+                      "title", _("_Account Description"),
                       "text", account_name,
                       "show-apply-button", TRUE,
                       "use-underline", TRUE,
@@ -888,6 +888,13 @@ goa_provider_dialog_push_account (GoaProviderDialog *self,
                     self);
   adw_preferences_group_add (ADW_PREFERENCES_GROUP (group), row);
 
+  // Gvfs requires a user and host for OneDrive mount spec, so disallow
+  // custom presentation identities for this provider
+  if (g_str_equal (goa_provider_get_provider_type (self->provider), GOA_MS_GRAPH_NAME))
+    {
+      gtk_editable_set_editable (GTK_EDITABLE (row), FALSE);
+    }
+
   revealer = gtk_revealer_new ();
   gtk_revealer_set_transition_type (GTK_REVEALER (revealer), GTK_REVEALER_TRANSITION_TYPE_CROSSFADE);
   adw_preferences_group_add (ADW_PREFERENCES_GROUP (group), revealer);
@@ -1409,7 +1416,7 @@ goa_provider_task_run_in_dialog (GTask             *task,
                            "closed",
                            G_CALLBACK (goa_provider_task_run_in_dialog_cb),
                            g_object_ref (task),
-                           0 /* G_CONNECT_DEFAULT */);
+                           G_CONNECT_DEFAULT);
   g_object_set_data (G_OBJECT (task), "goa-provider-dialog", dialog);
 
   /* Ensure the handler runs if the task is cancelled.
