@@ -25,8 +25,9 @@
 #include <glib/gi18n.h>
 #include <gio/gio.h>
 
-struct _GoaKerberosIdentityInquiryPrivate
+struct _GoaKerberosIdentityInquiry
 {
+  GObject parent;
   GoaIdentity *identity;
   char *name;
   char *banner;
@@ -50,7 +51,6 @@ static void initable_interface_init (GInitableIface *interface);
 G_DEFINE_TYPE_WITH_CODE (GoaKerberosIdentityInquiry,
                          goa_kerberos_identity_inquiry,
                          G_TYPE_OBJECT,
-                         G_ADD_PRIVATE (GoaKerberosIdentityInquiry)
                          G_IMPLEMENT_INTERFACE (G_TYPE_INITABLE,
                                                 initable_interface_init)
                          G_IMPLEMENT_INTERFACE (GOA_TYPE_IDENTITY_INQUIRY,
@@ -100,9 +100,9 @@ goa_kerberos_identity_inquiry_dispose (GObject *object)
 {
   GoaKerberosIdentityInquiry *self = GOA_KERBEROS_IDENTITY_INQUIRY (object);
 
-  g_clear_object (&self->priv->identity);
-  g_clear_pointer (&self->priv->name, g_free);
-  g_clear_pointer (&self->priv->banner, g_free);
+  g_clear_object (&self->identity);
+  g_clear_pointer (&self->name, g_free);
+  g_clear_pointer (&self->banner, g_free);
 
   G_OBJECT_CLASS (goa_kerberos_identity_inquiry_parent_class)->dispose (object);
 }
@@ -112,7 +112,7 @@ goa_kerberos_identity_inquiry_finalize (GObject *object)
 {
   GoaKerberosIdentityInquiry *self = GOA_KERBEROS_IDENTITY_INQUIRY (object);
 
-  g_list_free_full (self->priv->queries, (GDestroyNotify) goa_kerberos_identity_query_free);
+  g_list_free_full (self->queries, (GDestroyNotify) goa_kerberos_identity_query_free);
 
   G_OBJECT_CLASS (goa_kerberos_identity_inquiry_parent_class)->finalize (object);
 }
@@ -131,9 +131,6 @@ goa_kerberos_identity_inquiry_class_init (GoaKerberosIdentityInquiryClass *klass
 static void
 goa_kerberos_identity_inquiry_init (GoaKerberosIdentityInquiry *self)
 {
-  self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self,
-                                            GOA_TYPE_KERBEROS_IDENTITY_INQUIRY,
-                                            GoaKerberosIdentityInquiryPrivate);
 }
 
 GoaIdentityInquiry *
@@ -157,23 +154,23 @@ goa_kerberos_identity_inquiry_new (GoaKerberosIdentity * identity,
   self = GOA_KERBEROS_IDENTITY_INQUIRY (object);
 
   /* FIXME: make these construct properties */
-  self->priv->identity = g_object_ref (GOA_IDENTITY (identity));
-  self->priv->name = g_strdup (name);
-  self->priv->banner = g_strdup (banner);
+  self->identity = g_object_ref (GOA_IDENTITY (identity));
+  self->name = g_strdup (name);
+  self->banner = g_strdup (banner);
 
-  self->priv->number_of_queries = 0;
+  self->number_of_queries = 0;
   for (i = 0; i < number_of_prompts; i++)
     {
       GoaKerberosIdentityQuery *query;
 
       query = goa_kerberos_identity_query_new (inquiry, &prompts[i]);
 
-      self->priv->queries = g_list_prepend (self->priv->queries, query);
-      self->priv->number_of_queries++;
+      self->queries = g_list_prepend (self->queries, query);
+      self->number_of_queries++;
     }
-  self->priv->queries = g_list_reverse (self->priv->queries);
+  self->queries = g_list_reverse (self->queries);
 
-  self->priv->number_of_unanswered_queries = self->priv->number_of_queries;
+  self->number_of_unanswered_queries = self->number_of_queries;
 
   error = NULL;
   if (!g_initable_init (G_INITABLE (self), NULL, &error))
@@ -195,8 +192,7 @@ goa_kerberos_identity_inquiry_get_identity (GoaIdentityInquiry *inquiry)
   g_return_val_if_fail (GOA_IS_KERBEROS_IDENTITY_INQUIRY (inquiry), NULL);
 
   self = GOA_KERBEROS_IDENTITY_INQUIRY (inquiry);
-
-  return self->priv->identity;
+  return self->identity;
 }
 
 static char *
@@ -207,8 +203,7 @@ goa_kerberos_identity_inquiry_get_name (GoaIdentityInquiry *inquiry)
   g_return_val_if_fail (GOA_IS_KERBEROS_IDENTITY_INQUIRY (inquiry), NULL);
 
   self = GOA_KERBEROS_IDENTITY_INQUIRY (inquiry);
-
-  return g_strdup (self->priv->name);
+  return g_strdup (self->name);
 }
 
 static char *
@@ -219,8 +214,7 @@ goa_kerberos_identity_inquiry_get_banner (GoaIdentityInquiry *inquiry)
   g_return_val_if_fail (GOA_IS_KERBEROS_IDENTITY_INQUIRY (inquiry), NULL);
 
   self = GOA_KERBEROS_IDENTITY_INQUIRY (inquiry);
-
-  return g_strdup (self->priv->banner);
+  return g_strdup (self->banner);
 }
 
 static gboolean
@@ -231,8 +225,7 @@ goa_kerberos_identity_inquiry_is_complete (GoaIdentityInquiry *inquiry)
   g_return_val_if_fail (GOA_IS_KERBEROS_IDENTITY_INQUIRY (inquiry), FALSE);
 
   self = GOA_KERBEROS_IDENTITY_INQUIRY (inquiry);
-
-  return self->priv->number_of_unanswered_queries == 0 || self->priv->is_failed;
+  return self->number_of_unanswered_queries == 0 || self->is_failed;
 }
 
 static gboolean
@@ -243,8 +236,7 @@ goa_kerberos_identity_inquiry_is_failed (GoaIdentityInquiry *inquiry)
   g_return_val_if_fail (GOA_IS_KERBEROS_IDENTITY_INQUIRY (inquiry), FALSE);
 
   self = GOA_KERBEROS_IDENTITY_INQUIRY (inquiry);
-
-  return self->priv->is_failed;
+  return self->is_failed;
 }
 
 static void
@@ -257,9 +249,9 @@ goa_kerberos_identity_inquiry_mark_query_answered (GoaKerberosIdentityInquiry *
     }
 
   query->is_answered = TRUE;
-  self->priv->number_of_unanswered_queries--;
+  self->number_of_unanswered_queries--;
 
-  if (self->priv->number_of_unanswered_queries == 0)
+  if (self->number_of_unanswered_queries == 0)
     {
       _goa_identity_inquiry_emit_complete (GOA_IDENTITY_INQUIRY (self));
     }
@@ -268,7 +260,7 @@ goa_kerberos_identity_inquiry_mark_query_answered (GoaKerberosIdentityInquiry *
 static void
 goa_kerberos_identity_inquiry_fail (GoaKerberosIdentityInquiry *self)
 {
-  self->priv->is_failed = TRUE;
+  self->is_failed = TRUE;
   _goa_identity_inquiry_emit_complete (GOA_IDENTITY_INQUIRY (self));
 }
 
@@ -308,8 +300,7 @@ goa_kerberos_identity_inquiry_iter_init (GoaIdentityInquiryIter * iter,
                                          GoaIdentityInquiry * inquiry)
 {
   GoaKerberosIdentityInquiry *self = GOA_KERBEROS_IDENTITY_INQUIRY (inquiry);
-
-  iter->data = self->priv->queries;
+  iter->data = self->queries;
 }
 
 static GoaIdentityQuery *
@@ -342,17 +333,17 @@ goa_kerberos_identity_query_get_mode (GoaIdentityInquiry * inquiry,
   GoaKerberosIdentityQuery *kerberos_query = (GoaKerberosIdentityQuery *) query;
 
   g_return_val_if_fail (GOA_IS_KERBEROS_IDENTITY_INQUIRY (inquiry),
-                        GOA_KERBEROS_IDENTITY_QUERY_MODE_INVISIBLE);
+                        GOA_IDENTITY_QUERY_MODE_INVISIBLE);
   g_return_val_if_fail (inquiry == kerberos_query->inquiry,
-                        GOA_KERBEROS_IDENTITY_QUERY_MODE_INVISIBLE);
+                        GOA_IDENTITY_QUERY_MODE_INVISIBLE);
 
   if (kerberos_query->kerberos_prompt->hidden)
     {
-      return GOA_KERBEROS_IDENTITY_QUERY_MODE_INVISIBLE;
+      return GOA_IDENTITY_QUERY_MODE_INVISIBLE;
     }
   else
     {
-      return GOA_KERBEROS_IDENTITY_QUERY_MODE_VISIBLE;
+      return GOA_IDENTITY_QUERY_MODE_VISIBLE;
     }
 }
 
@@ -363,7 +354,7 @@ goa_kerberos_identity_query_get_prompt (GoaIdentityInquiry * inquiry,
   GoaKerberosIdentityQuery *kerberos_query = (GoaKerberosIdentityQuery *) query;
 
   g_return_val_if_fail (GOA_IS_KERBEROS_IDENTITY_INQUIRY (inquiry),
-                        GOA_KERBEROS_IDENTITY_QUERY_MODE_INVISIBLE);
+                        GOA_IDENTITY_QUERY_MODE_INVISIBLE);
   g_return_val_if_fail (inquiry == kerberos_query->inquiry, NULL);
 
   return g_strdup (kerberos_query->kerberos_prompt->prompt);
@@ -376,7 +367,7 @@ goa_kerberos_identity_query_is_answered (GoaIdentityInquiry * inquiry,
   GoaKerberosIdentityQuery *kerberos_query = (GoaKerberosIdentityQuery *) query;
 
   g_return_val_if_fail (GOA_IS_KERBEROS_IDENTITY_INQUIRY (inquiry),
-                        GOA_KERBEROS_IDENTITY_QUERY_MODE_INVISIBLE);
+                        GOA_IDENTITY_QUERY_MODE_INVISIBLE);
   g_return_val_if_fail (inquiry == kerberos_query->inquiry, FALSE);
 
   return kerberos_query->is_answered;
